@@ -1,16 +1,9 @@
-"""
-Checking specifics portal settings.
+"""Checking specifics portal settings.
 This package must run in a leaflet package (needs app_config.py)
 """
-
 import unittest2 as unittest
-
 from base import IntegrationTestCase
 
-from Products.CMFCore.utils import getToolByName
-
-# adapt if any need to your testing utils module.
-from collective.js.leaflet.tests.globals import *
 
 class TestSetup(IntegrationTestCase):
     """Check Policy."""
@@ -18,11 +11,8 @@ class TestSetup(IntegrationTestCase):
     def test_Noop(self):
         self.assertEquals(True, True)
 
-def test_suite():
-    """."""
-    suite = unittest.TestSuite()
-    suite.addTests(
-        unittest.defaultTestLoader.loadTestsFromName(
-            __name__))
-    return suite  
 
+def test_suite():
+    suite = unittest.TestSuite()
+    suite.addTests(unittest.defaultTestLoader.loadTestsFromName(__name__))
+    return suite
